Welcome to Thumbor’s documentation! — Thumbor 7.0.0a2 documentation

# Welcome to Thumbor’s documentation!

## Whats Thumbor?

Thumbor is a smart imaging service. It enables on-demand crop, resizing and flipping of images.

It features a VERY smart detection of important points in the image for better cropping and resizing, using state-of-the-art face and feature detection algorithms (more on that in Detection Algorithms).

Using thumbor is very easy (after it is running). All you have to do is access it using an URL for an image, like this:

    http://thumbor-server/unsafe/300x200/smart/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg

That URL would show an image of the big brother brasil participants in 300x200 using smart crop. There are several other options to the image URL configuration. You can check them in the Usage page. For more details on the /unsafe part of the URL, check the Security page.

The safe url for the above URL would look like (check Security for more details):

    http://thumbor-server/K97LekICOXT9MbO3X1u8BBkrjbu5/300x200/smart/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg

Warning

Release 7.0.0 introduces a major breaking change due to the migration to python 3 and the modernization of our codebase. Please read the release notes for details on how to upgrade.

## Contents

- Installing
  - Stable
  - Ubuntu/Debian using aptitude (apt-get)
  - From the source of a stable release
  - From the latest version of the source
- Getting Started
  - Problems installing thumbor locally
  - Changing its size
  - Flipping the image
  - Filters
  - What now?
- Usage
  - Image Endpoint
  - Metadata Endpoint
- Imaging
  - Crop and Resize Algorithms
  - Filters
  - Detectors
  - Image loader
  - Image storage
  - Result Storage
  - Optimizers
- Customizing Thumbor
  - Custom Storages
  - Custom Image Loaders
  - Custom Result Storages
  - Custom Filters
  - Custom Engines
  - Custom detection
  - Custom Image Optimizers
  - Custom Error Handlers
  - Custom Handler Lists
  - Plugins
  - Libraries
- Administration
  - Configuration
  - Automated Error Handling
  - Hosting
  - Logging
  - Running thumbor server
  - Image Metadata
  - Security
- Upload
  - How to upload Images
  - Posting, Putting and Deleting
  - Creating my own Storage
- Contributors & Users
  - The team
  - Whos using it
  - Hacking on Thumbor
  - Licensing

# Indices and tables

- Index

- Module Index

- Search Page